/* eslint-disable no-unused-vars */
'use strict';

module.exports = app => {
  const { STRING, INTEGER, ENUM, DATE, TEXT } = app.Sequelize;

  const Item = app.model.define(
    'item',
    {
      id: { type: INTEGER, primaryKey: true, autoIncrement: true },
      project_id: {
        type: INTEGER,
        allowNull: true,
        comment: '所属项目',
        unique: true,
      },
      step_id: {
        type: INTEGER,
        allowNull: true,
        comment: '所属步骤',
        unique: true,
      },
      userid: {
        type: INTEGER,
        allowNull: true,
        comment: '开发负责人',
        unique: true,
      },
      mission_name: {
        type: STRING(255),
        allowNull: true,
        comment: '任务名称',
        unique: true,
      },
      deadline: {
        type: DATE,
        allowNull: true,
        comment: '截止日期',
        unique: true,
      },
      status: {
        type: ENUM('0', '1', '2', '3', '4', '5'),
        allowNull: false,
        defaultValue: '0',
        comment: '状态',
        unique: true,
      },
      other: {
        type: STRING(255),
        allowNull: true,
        comment: '冗余字段',
        unique: true,
      },
      sort: {
        type: INTEGER,
        allowNull: true,
        comment: '排序',
        unique: true,
      },
      remark: {
        type: TEXT,
        allowNull: true,
        comment: '备注',
        unique: true,
      },
      created_at: DATE,
      updated_at: DATE,
    },
    {
      timestamps: true,
      createdAt: 'created_at',
      updatedAt: 'updated_at',
    }
  );
  return Item;
};

//     freezeTableName: true,  使用自定义表名
//     // 实例对应的表名
//     tableName: 'user',
//     // 如果需要sequelize帮你维护createdAt,updatedAt和deletedAt必须先启用timestamps功能
//     // 将createdAt对应到数据库的created_at字段
//     createdAt: 'created_at',
//     // 将updatedAt对应到数据库的updated_at字段
//     updatedAt: 'updated_at',
//     //And deletedAt to be called destroyTime (remember to enable paranoid for this to work)
//     deletedAt: false, //'deleted_at',
//     //删除数据时不删除数据，而是更新deleteAt字段 如果需要设置为true，则上面的deleteAt字段不能为false，也就是说必须启用
//     paranoid: false
